Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ATACADAO S.A.
CNPJ: 75.315.333/0121-15 Inscrição Estadual: 1090362886
ROD RST 287, 5500, CAMOBI, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 120672 Série: 509 Data de Emissão: 25/10/2019 13:17:57
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1075 3153 3301 2115 6550 9000 1206 7210 4857 9176
Protocolo de Autorização: 143191467812359
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
57748944 | SHAMP.TRESEMME | 1 | UN | 13,9 | 13,90
23290909 | CR.LEITE PIRACANJUBA | 2 | UN | 1,95 | 3,90
41208971 | LEITE FERM.ACTIVIA M | 1 | UN | 8,99 | 8,99
64931937 | SAB.FRANCIS CLASSICO | 1 | UN | 7,9 | 7,90
64930972 | SAB.FRANCIS CLASSICO | 1 | UN | 7,9 | 7,90
8709976 | TOMATE S/PEL.MASTRO. | 5 | UN | 3,95 | 19,75
29001970 | MOLHO TOM.FUGINI TRA | 2 | UN | 1,3 | 2,60
15267648 | ATUM COQUEIRO SOLIDO | 4 | UN | 6,95 | 27,80
29746924 | AGUA KERO COCO | 2 | UN | 6,99 | 13,98
28850933 | AGUA M.FLORESTA PET | 8 | UN | 4,29 | 34,32
1075102 | MELANCIA GD | 1 | UN | 7,99 | 7,99
63724957 | LIMP.VEJA | 1 | UN | 7,9 | 7,90
58890943 | GELATINA DR.OETKER | 2 | UN | 0,79 | 1,58
58887987 | GELATINA DR.OETKER | 2 | UN | 0,79 | 1,58
53013994 | SAB.FARNESE | 1 | UN | 1,09 | 1,09
53012934 | SAB.FARNESE | 1 | UN | 1,09 | 1,09
52939917 | SAB.FARNESE | 1 | UN | 1,09 | 1,09
52938958 | SAB.FARNESE | 1 | UN | 1,09 | 1,09
4921422 | MANDIOCA PACOTE | 1 | UN | 4,99 | 4,99
1646951 | BANANA PRATA | 1,26 | KG | 3,99 | 5,03
2488999 | LARANJA PERA Kg | 2,874 | KG | 1,99 | 5,72
8322970 | BUCHA VEG.PED. NATU | 1 | UN | 3,9 | 3,90
1825917 | MACA NAC.GALA | 0,938 | KG | 5,49 | 5,15
62467977 | SABONETEIRA PLASVALE | 1 | UN | 1,79 | 1,79
14691938 | BATATA LAVADA | 1,354 | KG | 1,89 | 2,56
1908912 | BATATA DOCE | 1,956 | KG | 1,99 | 3,89
62251960 | SAB.LIQ.LUX REF. | 1 | UN | 3,35 | 3,35
25668916 | ACUC.REF.CARAVELAS | 1 | UN | 2,19 | 2,19
61164927 | ACUCAR MASCAVO | 1 | UN | 9,98 | 9,98
54636962 | BISC.CLUB SOCIAL | 1 | UN | 4,29 | 4,29
28961968 | CHA BARAO VERDE | 1 | UN | 2,4 | 2,40
45268950 | OVO PVC CAIPIRA | 1 | UN | 14,49 | 14,49
Valor total R$ | 229,36
Valor descontos R$ | 4,82
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:47